package com.vendor.burn.model.devices.burners;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.model.BurnContext;
import com.vendor.burn.model.FileSystem;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.BurnStatus;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.model.define.IUploadable;
import com.vendor.burn.model.devices.IEmmcBurner;
import com.vendor.burn.model.devices.ITab;
import com.vendor.burn.model.devices.burners.PartitionBurner;
import com.vendor.burn.model.event.EventType;
import com.vendor.burn.model.event.FastbootEvent;
import com.vendor.burn.model.monitor.CmdMonitor;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.serial.workers.AbstractBurnerWorker;
import com.vendor.burn.serial.workers.EmmcPartitionBurnerWorker;
import com.vendor.burn.serial.workers.PartitionBurnerWorker;
import com.vendor.burn.sparse.SparseFileAgent;
import com.vendor.burn.ui.burners.tabs.EmmcTab;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.IJobChangeListener;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.FileDialog;
import org.vendor.tftp.tool.TFTPService;

public class EmmcBurner extends PartitionBurner implements IEmmcBurner, IUploadable {
  protected static final String msg_the_partition_size_can_not_be_null_in_row_ = Messages.PartitionBurner_msg_the_partition_size_can_not_be_null_in_row_;
  
  private boolean createPartitionTable = true;
  
  private String emmcImgOutPath;
  
  protected final EmmcPartitionBurnerWorker worker = getBurnerWorker();
  
  public EmmcBurner(BurnContext burnContext) {
    super(burnContext);
    getChildren().clear();
    PartitionItem fastboot = new PartitionItem();
    fastboot.setName("fastboot");
    fastboot.setFileSystem(FileSystem.none);
    fastboot.setFlashType(FlashType.emmc);
    getChildren().add(fastboot);
  }
  
  public void burn(IFastbootProgressMonitor fastbootMonitor) {
    BurnContext context = getBurnContext();
    EmmcPartitionBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    if (worker.isNeedSetupNet(getBurnContext().getTransferWay())) {
      boolean start = false;
      InetAddress address = null;
      try {
        address = InetAddress.getByName("x.x.x.x");
      } catch (UnknownHostException unknownHostException) {}
      int port = FastbootPreferences.getInt("vendor.burn.tftp.port");
      try {
        if (context.getTransferWay() == TransferWay.UsbTransNet)
          TFTPService.setUsb2EtherNet(true); 
        start = TFTPService.TFTPSERVICE.start(getParentFile(), address, ToolUtils.getPortCmd(), port);
        getTftpPreferenceValue();
        context.setTftpOccupied(!start);
      } catch (IOException e) {
        context.setTftpOccupied(true);
        handleTftpStartFailed();
      } finally {
        if (!start)
          fastbootMonitor.warnln(Messages.PartitionBurner_msg_start_Tftp_server_failed_on_port_69); 
      } 
    } 
    if (fastbootMonitor != null) {
      FastbootEvent event = fastbootMonitor.getEvent();
      Object object = new Object(this, "Burn By Partition", fastbootMonitor, worker, event);
      showProgressDialog((Job)object);
      object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
      object.schedule();
    } 
  }
  
  private File getParentFile() {
    if (this.children == null || this.children.isEmpty())
      return null; 
    for (PartitionItem partition : this.children) {
      if (partition.isChecked() && 
        partition.getFile() != null)
        return partition.getFile().getParentFile(); 
    } 
    return null;
  }
  
  public void erase(IFastbootProgressMonitor fastbootMonitor) {
    if (fastbootMonitor == null)
      return; 
    fastbootMonitor.getEvent().init(EventType.ERASE);
    EmmcPartitionBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    Object object = new Object(this, "Erase all devices", fastbootMonitor, worker);
    showProgressDialog((Job)object);
    object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
    object.schedule();
  }
  
  public List<String> getSteps() {
    List<String> steps = new ArrayList<>();
    steps.add(Messages.EmmcBurner_Step_1);
    steps.add(Messages.EmmcBurner_Step_2);
    steps.add(Messages.EmmcBurner_Step_3);
    steps.add(Messages.EmmcBurner_Step_4);
    steps.add(Messages.EmmcBurner_Step_5);
    steps.add(Messages.EmmcBurner_Step_6);
    return steps;
  }
  
  protected IStatus checkOtherPart(List<PartitionItem> parts, EventType event) {
    FlashType[] flashTypes = FlashType.getFlashTypes(this);
    FileSystem[] fileSystems = FileSystem.getFileSystems(this);
    boolean createTable = isCreatePartitionTable();
    long lastAddress = 0L;
    int size = parts.size();
    IStatus result = Status.OK_STATUS;
    for (int partIndex = 0; partIndex < size; partIndex++) {
      PartitionItem part = parts.get(partIndex);
      if (part.isChecked() || (
        event == EventType.BURN && !createTable)) {
        result = checkFlashAndFileSystem(flashTypes, fileSystems, partIndex, part);
        if (result != Status.OK_STATUS)
          return result; 
        result = checkStartAddressAndLen(part, size, partIndex);
        if (result != Status.OK_STATUS) {
          highLight(part);
          return result;
        } 
        long start = part.getStart();
        if (0L == part.getLength()) {
          highLight(part);
          return error(NLS.bind(Messages.AbstractBurner_msg_the_partition_length_must_be_nonzero_in_row_, 
                Integer.valueOf(partIndex + 1)));
        } 
        boolean isCheckStart = (partIndex != 1 || !FastbootView.isChipBranchSeries9());
        if (isCheckStart && start < lastAddress) {
          highLight(part);
          return error(NLS.bind(Messages.AbstractBurner_messgae_the_partition_address_must_be_greater_than_the_used_size_in_row_, 
                
                Integer.valueOf(partIndex + 1)));
        } 
        lastAddress = start + ((part.getLength() == -1L) ? 0L : part.getLength());
        if (part.isChecked()) {
          File file = part.getFile();
          int alignLen = 512;
          if (part.getFlashType() == FlashType.ufs)
            alignLen = 4096; 
          if (start % alignLen != 0L) {
            highLight(part);
            return error(NLS.bind(Messages.PartitionBurner_msg_partition_Start_should_be_with_unit_KorM_or_NK_times, 
                  Integer.valueOf(alignLen), 
                  Integer.valueOf(partIndex + 1)));
          } 
          boolean vaildLen = (part.getLength() != -1L && part.getLength() % alignLen != 0L);
          if (vaildLen) {
            highLight(part);
            return error(NLS.bind(Messages.PartitionBurner_msg_Length_must_be_NK_times_that_is_should_be_with_unit_K_or_M_in_row_, 
                  
                  Integer.valueOf(alignLen), Integer.valueOf(partIndex + 1)));
          } 
          if (EventType.BURN == event) {
            result = checkBurn(size, partIndex, part, file);
          } else if (EventType.UPLOAD == event) {
            result = checkUpload(size, partIndex, part, file);
          } 
          if (result != Status.OK_STATUS)
            return result; 
          try {
            boolean checkTftpFileNameVaild = (file != null && (getBurnContext().getTransferWay() == TransferWay.Net || getBurnContext().getTransferWay() == TransferWay.UsbTransNet || getBurnContext().getTransferWay() == TransferWay.JTAGAndNet) && (file.getName().getBytes(System.getProperty("file.encoding"))).length > 100);
            if (checkTftpFileNameVaild)
              return error(NLS.bind(Messages.msg_File_name_is_too_long_please_use_a_short_name_instead, 
                    Integer.valueOf(partIndex + 1))); 
          } catch (UnsupportedEncodingException unsupportedEncodingException) {}
        } 
      } 
    } 
    return Status.OK_STATUS;
  }
  
  protected IStatus checkUpload(int size, int partIndex, PartitionItem part, File file) {
    if (file == null) {
      highLight(part);
      return error(NLS.bind(Messages.AbstractBurner_msg_file_path_does_not_select_in_row_, Integer.valueOf(partIndex + 1)));
    } 
    boolean checkLastPartLen = (size - 1 != partIndex && part.getLength() == -1L);
    if (checkLastPartLen) {
      highLight(part);
      return error(NLS.bind(msg_the_partition_size_can_not_be_null_in_row_, Integer.valueOf(partIndex + 1)));
    } 
    if (file.exists()) {
      boolean openConfirm = false;
      try {
        openConfirm = MessageDialog.openQuestion(
            Display.getDefault().getActiveShell(), Messages.FASTBOOT_CONFIRM_Title, 
            
            NLS.bind(Messages.PartitionComposite_msg_file_exists_already_whether_to_overwrite_it, file
              .getCanonicalPath()));
      } catch (IOException e) {
        return Status.CANCEL_STATUS;
      } 
      if (!openConfirm) {
        highLight(part);
        return error(Messages.AbstractBurner_msg_file_exists_please_check_file);
      } 
    } 
    return Status.OK_STATUS;
  }
  
  protected IStatus checkBurn(int size, int partIndex, PartitionItem part, File file) {
    boolean checkLastLen = (part.getLength() == -1L && size - 1 != partIndex);
    if (checkLastLen) {
      highLight(part);
      return error(NLS.bind(msg_the_partition_size_can_not_be_null_in_row_, Integer.valueOf(partIndex + 1)));
    } 
    if (file != null) {
      if (!file.exists()) {
        highLight(part);
        return error(NLS.bind(Messages.AbstractBurner_msg_file_does_not_exist_in_row_, file
              .getName(), Integer.valueOf(partIndex + 1)));
      } 
      if (file.isDirectory()) {
        highLight(part);
        return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_a_directory, Integer.valueOf(partIndex + 1)));
      } 
      FileInputStream fileInputStream = null;
      try {
        fileInputStream = new FileInputStream(file);
      } catch (Exception e) {
        highLight(part);
        return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_opened_in_row_, Integer.valueOf(partIndex + 1)));
      } finally {
        if (fileInputStream != null)
          try {
            fileInputStream.close();
          } catch (Exception exception) {} 
      } 
      if (0L == file.length()) {
        highLight(part);
        return error(NLS.bind(Messages.AbstractBurner_msg_the_file_size_must_be_nonzero_in_row_, 
              Integer.valueOf(partIndex + 1)));
      } 
      boolean vaildLen = (part.getLength() != -1L && part.getLength() < file.length());
      if (vaildLen) {
        highLight(part);
        return error(NLS.bind(Messages.PartitionBurner_msg_invalid_partition_size_in_row_, part
              .getFile().getName()));
      } 
    } 
    return Status.OK_STATUS;
  }
  
  protected IStatus checkStartAddressAndLen(PartitionItem part, int partSize, int partIndex) {
    long start = part.getStart();
    if (0 == partIndex && start != 0L)
      return error(Messages.PartitionBurner_msg_invalid_fastboot_start); 
    return super.checkStartAddressAndLen(part, partSize, partIndex);
  }
  
  private IStatus checkFlashAndFileSystem(FlashType[] flashTypes, FileSystem[] fileSystems, int partIndex, PartitionItem part) {
    boolean valid = false;
    for (FileSystem fileSystem : fileSystems) {
      if (fileSystem == part.getFileSystem()) {
        valid = true;
        break;
      } 
    } 
    if (!valid) {
      highLight(part);
      return error(NLS.bind(Messages.AbstractBurner_msg_invalid_file_system_in_row_, Integer.valueOf(partIndex + 1)));
    } 
    valid = false;
    for (FlashType flashType : flashTypes) {
      if (part.getFlashType().toString().indexOf(flashType.toString()) != -1) {
        valid = true;
        break;
      } 
    } 
    if (!valid) {
      highLight(part);
      return error(NLS.bind(Messages.AbstractBurner_msg_invalid_flash_type_in_row_, Integer.valueOf(partIndex + 1)));
    } 
    return Status.OK_STATUS;
  }
  
  public IStatus checkBeforeUpload() {
    IStatus validLocalConfig = validSerialPort();
    if (!isOK(validLocalConfig))
      return validLocalConfig; 
    IStatus check = validNetConfig();
    if (!isOK(check))
      return check; 
    TransferWay transferWay = getBurnContext().getTransferWay();
    if (transferWay == TransferWay.USBBootrom || transferWay == TransferWay.USBNonNude || transferWay == TransferWay.UsbAndSerial)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, "USB")); 
    if (transferWay == TransferWay.I2CBootrom)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, "I2C")); 
    if (transferWay == TransferWay.Serial)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, Messages.FastbootView_TransferWay_Serial)); 
    check = checkTable(EventType.UPLOAD);
    if (!isOK(check))
      return check; 
    return null;
  }
  
  public IStatus checkBeforeBurn() {
    IStatus validLocalConfig = validSerialPort();
    if (!isOK(validLocalConfig))
      return validLocalConfig; 
    IStatus check = validNetConfig();
    if (!isOK(check))
      return check; 
    check = checkTable(EventType.BURN);
    if (!isOK(check))
      return check; 
    if (!isOK(checkHasSelectNullFile()))
      return Status.CANCEL_STATUS; 
    return Status.OK_STATUS;
  }
  
  protected IStatus checkTable(EventType event) {
    boolean createTable = isCreatePartitionTable();
    List<PartitionItem> parts = getChildren();
    int selection = 0;
    for (PartitionItem partitionItem : parts) {
      if (partitionItem.isChecked()) {
        selection++;
        break;
      } 
    } 
    if (0 == selection) {
      if (event == EventType.UPLOAD)
        return error(Messages.AbstractBurner_msg_emmc_no_createTable_and_non_partition); 
      if (!createTable && event == EventType.BURN)
        return error(Messages.AbstractBurner_msg_emmc_no_createTable_and_non_partition); 
      return error(Messages.AbstractBurner_msg_emmc_no_createTable_and_non_partition);
    } 
    IStatus check = checkOtherPart(parts, event);
    if (!isOK(check))
      return check; 
    return Status.OK_STATUS;
  }
  
  public EmmcPartitionBurnerWorker getBurnerWorker() {
    return new EmmcPartitionBurnerWorker(this);
  }
  
  public void upload(IFastbootProgressMonitor fastbootMonitor) {
    EmmcPartitionBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    TransferWay transferWay = getBurnContext().getTransferWay();
    if (fastbootMonitor != null)
      fastbootMonitor.begin(); 
    if (worker.isNeedSetupNet(transferWay)) {
      File home = worker.getHome(getChildren(), EventType.UPLOAD);
      boolean start = false;
      InetAddress address = null;
      try {
        address = InetAddress.getByName("x.x.x.x");
      } catch (UnknownHostException unknownHostException) {}
      int port = FastbootPreferences.getInt("vendor.burn.tftp.port");
      try {
        start = TFTPService.TFTPSERVICE.start(home, address, ToolUtils.getPortCmd(), port);
        getTftpPreferenceValue();
      } catch (Exception e) {
        handleTftpStartFailed();
      } finally {
        if (!start)
          fastbootMonitor.warnln(Messages.PartitionBurner_msg_start_Tftp_server_failed_on_port_69); 
      } 
    } 
    if (fastbootMonitor != null) {
      FastbootEvent event = fastbootMonitor.getEvent();
      event.setBurner((IBurner)this);
      Object object = new Object(this, "Upload By Emmc Partition", worker, event, fastbootMonitor);
      showProgressDialog((Job)object);
      object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
      object.schedule();
    } 
  }
  
  public boolean isCreatePartitionTable() {
    return this.createPartitionTable;
  }
  
  public void setCreatePartitionTable(boolean createPartitionTable) {
    this.createPartitionTable = createPartitionTable;
  }
  
  public ITab getTab() {
    return (ITab)new EmmcTab();
  }
  
  public int createImageCmdLine(IFastbootProgressMonitor fastbootMonitor) {
    this.worker.setProgressMonitor(fastbootMonitor);
    FastbootEvent event = fastbootMonitor.getEvent();
    File file = new File(this.emmcImgOutPath);
    boolean result = this.worker.createImage((IProgressMonitor)new CmdMonitor(), file, getChildren(), false);
    event.setSuccess(result);
    fastbootMonitor.finish();
    if (!result)
      return BurnStatus.MAKE_EMMC_IMAGE_FAILED.getErrorCode(); 
    return 0;
  }
  
  public void createImage(IFastbootProgressMonitor fastbootMonitor) {
    EmmcPartitionBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    FastbootEvent event = fastbootMonitor.getEvent();
    FileDialog d = new FileDialog(Display.getDefault().getActiveShell(), 8192);
    String open = d.open();
    if (open == null) {
      fastbootMonitor.finish();
      return;
    } 
    File file = new File(open);
    if (file.isDirectory()) {
      MessageDialog.openWarning(Display.getDefault().getActiveShell(), Messages.FASTBOOT_WARNING_Title, "Can not be a Directory!");
      fastbootMonitor.finish();
    } 
    Object object = new Object(this, "Making Image...", worker, file, event, fastbootMonitor);
    showProgressDialog((Job)object);
    object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
    object.schedule();
    fastbootMonitor.finish();
  }
  
  private void showResult(IFastbootProgressMonitor fastbootMonitor) {
    boolean isSuccess = fastbootMonitor.getEvent().isSuccess();
    if (isSuccess) {
      Display.getDefault().syncExec((Runnable)new Object(this));
    } else {
      Display.getDefault().syncExec((Runnable)new Object(this));
    } 
  }
  
  public IStatus checkCreateImage() {
    List<PartitionItem> children = getChildren();
    int size = children.size();
    if (children.isEmpty())
      return null; 
    long lastAddress = 0L;
    FlashType[] flashTypes = FlashType.getFlashTypes(this);
    FileSystem[] fileSystems = FileSystem.getFileSystems(this);
    IStatus result = Status.OK_STATUS;
    for (int i = 0; i < size; i++) {
      PartitionItem partition = children.get(i);
      long start = partition.getStart();
      if (0 == i && start != 0L) {
        highLight(partition);
        return error(Messages.PartitionBurner_msg_invalid_fastboot_start);
      } 
      if (0L == partition.getLength()) {
        highLight(partition);
        return error(NLS.bind(Messages.AbstractBurner_msg_the_partition_length_must_be_nonzero_in_row_, Integer.valueOf(i + 1)));
      } 
      if (start < lastAddress) {
        highLight(partition);
        return error(NLS.bind(Messages.AbstractBurner_messgae_the_partition_address_must_be_greater_than_the_used_size_in_row_, 
              
              Integer.valueOf(i + 1)));
      } 
      result = checkFlashAndFileSystem(flashTypes, fileSystems, i, partition);
      if (result != Status.OK_STATUS)
        return result; 
      lastAddress = start + ((partition.getLength() == -1L) ? 0L : partition.getLength());
      int alignLen = 512;
      if (partition.getFlashType() == FlashType.ufs)
        alignLen = 4096; 
      if (partition.getLength() == -1L && partition.getLength() % alignLen != 0L && i != size - 1) {
        highLight(partition);
        return error(NLS.bind(Messages.PartitionBurner_msg_Length_must_be_NK_times_that_is_should_be_with_unit_K_or_M_in_row_, 
              
              Integer.valueOf(alignLen), Integer.valueOf(i + 1)));
      } 
      if (partition.isChecked()) {
        File file = partition.getFile();
        if (file != null) {
          if (start % alignLen != 0L) {
            highLight(partition);
            return error(NLS.bind(Messages.PartitionBurner_msg_partition_Start_should_be_with_unit_KorM_or_NK_times, 
                  Integer.valueOf(alignLen), 
                  Integer.valueOf(i + 1)));
          } 
          if (file.exists()) {
            if (file.isDirectory()) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_a_directory, Integer.valueOf(i + 1)));
            } 
            FileInputStream fileInputStream = null;
            try {
              fileInputStream = new FileInputStream(file);
            } catch (Exception e) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_opened_in_row_, Integer.valueOf(i + 1)));
            } finally {
              if (fileInputStream != null)
                try {
                  fileInputStream.close();
                } catch (Exception exception) {} 
            } 
            if (0L == file.length()) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_size_must_be_nonzero_in_row_, Integer.valueOf(i + 1)));
            } 
            if (partition.getLength() != -1L && partition.getLength() < file.length()) {
              highLight(partition);
              return error(NLS.bind(Messages.PartitionBurner_msg_invalid_partition_size_in_row_, partition
                    .getFile().getName()));
            } 
          } 
        } 
      } 
    } 
    return null;
  }
  
  public IStatus checkCreateProImage() {
    List<PartitionItem> children = getChildren();
    int size = children.size();
    if (children.isEmpty())
      return null; 
    int index = 0;
    int selection = 0;
    for (index = 0; index < size; index++) {
      if (((PartitionItem)children.get(index)).isChecked()) {
        selection++;
        break;
      } 
    } 
    if (0 == selection)
      return error(Messages.PartitionBurner_msg_no_burning_partition); 
    long lastAddress = 0L;
    FlashType[] flashTypes = FlashType.getFlashTypes(this);
    FileSystem[] fileSystems = FileSystem.getFileSystems(this);
    IStatus result = Status.OK_STATUS;
    for (int i = 0; i < size; i++) {
      PartitionItem partition = children.get(i);
      long start = partition.getStart();
      if (partition.isChecked()) {
        boolean isBoot = (0 == i && start != 0L);
        if (isBoot) {
          highLight(partition);
          return error(Messages.PartitionBurner_msg_invalid_fastboot_start);
        } 
        if (0L == partition.getLength()) {
          highLight(partition);
          return error(NLS.bind(Messages.AbstractBurner_msg_the_partition_length_must_be_nonzero_in_row_, Integer.valueOf(i + 1)));
        } 
        if (start < lastAddress) {
          highLight(partition);
          return error(NLS.bind(Messages.AbstractBurner_messgae_the_partition_address_must_be_greater_than_the_used_size_in_row_, 
                
                Integer.valueOf(i + 1)));
        } 
        result = checkFlashAndFileSystem(flashTypes, fileSystems, i, partition);
        if (result != Status.OK_STATUS)
          return result; 
        lastAddress = start + ((partition.getLength() == -1L) ? 0L : partition.getLength());
        int alignLen = 512;
        if (partition.getFlashType() == FlashType.ufs)
          alignLen = 4096; 
        boolean vaildLen = (partition.isChecked() && partition.getLength() == -1L && partition.getLength() % alignLen != 0L && i != size - 1);
        if (vaildLen) {
          highLight(partition);
          return error(NLS.bind(Messages.PartitionBurner_msg_Length_must_be_NK_times_that_is_should_be_with_unit_K_or_M_in_row_, 
                
                Integer.valueOf(alignLen), Integer.valueOf(i + 1)));
        } 
        boolean notCheck = (!partition.isChecked() && !SparseFileAgent.isSparse(partition.getFileSystem()) && i != 0);
        if (!notCheck) {
          File file = partition.getFile();
          if (file != null) {
            boolean checkFileLen = ((SparseFileAgent.isSparse(partition.getFileSystem()) || i == 0) && partition.getFile().length() > partition.getLength() && partition.getLength() != -1L);
            if (checkFileLen) {
              highLight(partition);
              return error(NLS.bind(Messages.EmmcBurner_Insufficient_Partition_Length, Integer.valueOf(i + 1)));
            } 
            if (!file.exists()) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_file_does_not_exist_in_row_, Integer.valueOf(i + 1)));
            } 
            if (file.isDirectory()) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_a_directory, Integer.valueOf(i + 1)));
            } 
            FileInputStream fileInputStream = null;
            try {
              fileInputStream = new FileInputStream(file);
            } catch (Exception e) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_opened_in_row_, Integer.valueOf(i + 1)));
            } finally {
              if (fileInputStream != null)
                try {
                  fileInputStream.close();
                } catch (Exception exception) {} 
            } 
            if (0L == file.length()) {
              highLight(partition);
              return error(NLS.bind(Messages.AbstractBurner_msg_the_file_size_must_be_nonzero_in_row_, Integer.valueOf(i + 1)));
            } 
            vaildLen = (partition.getLength() != -1L && partition.getLength() < file.length());
            if (vaildLen) {
              highLight(partition);
              return error(NLS.bind(Messages.PartitionBurner_msg_invalid_partition_size_in_row_, partition
                    .getFile().getName()));
            } 
          } 
          if (start % alignLen != 0L) {
            highLight(partition);
            return error(NLS.bind(Messages.PartitionBurner_msg_partition_Start_should_be_with_unit_KorM_or_NK_times, 
                  Integer.valueOf(alignLen), 
                  Integer.valueOf(i + 1)));
          } 
        } 
      } 
    } 
    return null;
  }
  
  public void setEmmcImgOutPath(String emmcImgOutPath) {
    this.emmcImgOutPath = emmcImgOutPath;
  }
}
